# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from admobilize.proto.devicemanagement.v1alpha1 import device_manager_pb2 as admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2
from admobilize.proto.devicemanagement.v1alpha1 import resources_pb2 as admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DeviceManagerStub(object):
  """The service that an application uses to create, update, delete, manipulate and obtain
  devices.

  [START device management service]
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateDevice = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/CreateDevice',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.FromString,
        )
    self.GetDevice = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/GetDevice',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.GetDeviceRequest.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.FromString,
        )
    self.ListDevices = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/ListDevices',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ListDevicesRequest.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ListDevicesResponse.FromString,
        )
    self.UpdateDevice = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/UpdateDevice',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.UpdateDeviceRequest.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.FromString,
        )
    self.DeleteDevice = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/DeleteDevice',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.DeleteDeviceRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.ProvisionDevices = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/ProvisionDevices',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ProvisionDevicesRequest.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ProvisionDevicesResponse.FromString,
        )
    self.VerifyDeviceToken = channel.unary_unary(
        '/admobilize.devicemanagement.v1alpha1.DeviceManager/VerifyDeviceToken',
        request_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.VerifyDeviceTokenRequest.SerializeToString,
        response_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.FromString,
        )


class DeviceManagerServicer(object):
  """The service that an application uses to create, update, delete, manipulate and obtain
  devices.

  [START device management service]
  """

  def CreateDevice(self, request, context):
    """--- Standard methods -----------------------------------------------------------

    Creates a device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDevice(self, request, context):
    """Gets a device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDevices(self, request, context):
    """Lists devices in a project
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateDevice(self, request, context):
    """Updates a device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteDevice(self, request, context):
    """Deletes a device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ProvisionDevices(self, request, context):
    """--- Custom methods -----------------------------------------------------------

    Provision a device
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def VerifyDeviceToken(self, request, context):
    """Validates if a given token is a legitimate device token, this is
    the signature matches the registered public key
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateDevice': grpc.unary_unary_rpc_method_handler(
          servicer.CreateDevice,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.SerializeToString,
      ),
      'GetDevice': grpc.unary_unary_rpc_method_handler(
          servicer.GetDevice,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.GetDeviceRequest.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.SerializeToString,
      ),
      'ListDevices': grpc.unary_unary_rpc_method_handler(
          servicer.ListDevices,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ListDevicesRequest.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ListDevicesResponse.SerializeToString,
      ),
      'UpdateDevice': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateDevice,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.UpdateDeviceRequest.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.SerializeToString,
      ),
      'DeleteDevice': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteDevice,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.DeleteDeviceRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'ProvisionDevices': grpc.unary_unary_rpc_method_handler(
          servicer.ProvisionDevices,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ProvisionDevicesRequest.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.ProvisionDevicesResponse.SerializeToString,
      ),
      'VerifyDeviceToken': grpc.unary_unary_rpc_method_handler(
          servicer.VerifyDeviceToken,
          request_deserializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_device__manager__pb2.VerifyDeviceTokenRequest.FromString,
          response_serializer=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.Device.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'admobilize.devicemanagement.v1alpha1.DeviceManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/billing/v1alpha1/billing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/billing/v1alpha1/billing.proto',
  package='admobilize.billing.v1alpha1',
  syntax='proto3',
  serialized_options=_b('\n\037com.admobilize.billing.v1alpha1B\014BillingProtoP\001\242\002\005ADMBL\252\002\033AdMobilize.Billing.V1Alpha1'),
  serialized_pb=_b('\n)admobilize/billing/v1alpha1/billing.proto\x12\x1b\x61\x64mobilize.billing.v1alpha1\"B\n\x0e\x42illingAccount\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\"T\n\x12ProjectBillingInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1c\n\x14\x62illing_account_name\x18\x03 \x01(\tBW\n\x1f\x63om.admobilize.billing.v1alpha1B\x0c\x42illingProtoP\x01\xa2\x02\x05\x41\x44MBL\xaa\x02\x1b\x41\x64Mobilize.Billing.V1Alpha1b\x06proto3')
)




_BILLINGACCOUNT = _descriptor.Descriptor(
  name='BillingAccount',
  full_name='admobilize.billing.v1alpha1.BillingAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.billing.v1alpha1.BillingAccount.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='admobilize.billing.v1alpha1.BillingAccount.open', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='admobilize.billing.v1alpha1.BillingAccount.display_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=140,
)


_PROJECTBILLINGINFO = _descriptor.Descriptor(
  name='ProjectBillingInfo',
  full_name='admobilize.billing.v1alpha1.ProjectBillingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.project_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_account_name', full_name='admobilize.billing.v1alpha1.ProjectBillingInfo.billing_account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=226,
)

DESCRIPTOR.message_types_by_name['BillingAccount'] = _BILLINGACCOUNT
DESCRIPTOR.message_types_by_name['ProjectBillingInfo'] = _PROJECTBILLINGINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingAccount = _reflection.GeneratedProtocolMessageType('BillingAccount', (_message.Message,), dict(
  DESCRIPTOR = _BILLINGACCOUNT,
  __module__ = 'admobilize.billing.v1alpha1.billing_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.billing.v1alpha1.BillingAccount)
  ))
_sym_db.RegisterMessage(BillingAccount)

ProjectBillingInfo = _reflection.GeneratedProtocolMessageType('ProjectBillingInfo', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTBILLINGINFO,
  __module__ = 'admobilize.billing.v1alpha1.billing_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.billing.v1alpha1.ProjectBillingInfo)
  ))
_sym_db.RegisterMessage(ProjectBillingInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/common/entity.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/common/entity.proto',
  package='admobilize.common',
  syntax='proto3',
  serialized_options=_b('\n\034com.admobilize.common.EntityB\013EntityProtoP\001\242\002\005ADMCE\252\002\021AdMobilize.Common'),
  serialized_pb=_b('\n\x1e\x61\x64mobilize/common/entity.proto\x12\x11\x61\x64mobilize.common\x1a\x1fgoogle/protobuf/timestamp.proto\"6\n\nArrayValue\x12(\n\x06values\x18\x01 \x03(\x0b\x32\x18.admobilize.common.Value\"\xad\x02\n\x05Value\x12\x17\n\rboolean_value\x18\x01 \x01(\x08H\x00\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x31\n\x0c\x65ntity_value\x18\x06 \x01(\x0b\x32\x19.admobilize.common.EntityH\x00\x12\x34\n\x0b\x61rray_value\x18\t \x01(\x0b\x32\x1d.admobilize.common.ArrayValueH\x00\x12\x35\n\x0ftimestamp_value\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x16\n\x0cstring_value\x18\x11 \x01(\tH\x00\x12\x14\n\nblob_value\x18\x12 \x01(\x0cH\x00\x42\x0c\n\nvalue_type\"\x94\x01\n\x06\x45ntity\x12=\n\nproperties\x18\x01 \x03(\x0b\x32).admobilize.common.Entity.PropertiesEntry\x1aK\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.admobilize.common.Value:\x02\x38\x01\x42I\n\x1c\x63om.admobilize.common.EntityB\x0b\x45ntityProtoP\x01\xa2\x02\x05\x41\x44MCE\xaa\x02\x11\x41\x64Mobilize.Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='admobilize.common.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='admobilize.common.ArrayValue.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=140,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='admobilize.common.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='admobilize.common.Value.boolean_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='admobilize.common.Value.integer_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='admobilize.common.Value.double_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_value', full_name='admobilize.common.Value.entity_value', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='array_value', full_name='admobilize.common.Value.array_value', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_value', full_name='admobilize.common.Value.timestamp_value', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='admobilize.common.Value.string_value', index=6,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_value', full_name='admobilize.common.Value.blob_value', index=7,
      number=18, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_type', full_name='admobilize.common.Value.value_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=143,
  serialized_end=444,
)


_ENTITY_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='admobilize.common.Entity.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='admobilize.common.Entity.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='admobilize.common.Entity.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=595,
)

_ENTITY = _descriptor.Descriptor(
  name='Entity',
  full_name='admobilize.common.Entity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='admobilize.common.Entity.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENTITY_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=595,
)

_ARRAYVALUE.fields_by_name['values'].message_type = _VALUE
_VALUE.fields_by_name['entity_value'].message_type = _ENTITY
_VALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_VALUE.fields_by_name['timestamp_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['boolean_value'])
_VALUE.fields_by_name['boolean_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['integer_value'])
_VALUE.fields_by_name['integer_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['double_value'])
_VALUE.fields_by_name['double_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['entity_value'])
_VALUE.fields_by_name['entity_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['array_value'])
_VALUE.fields_by_name['array_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['timestamp_value'])
_VALUE.fields_by_name['timestamp_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_VALUE.oneofs_by_name['value_type'].fields.append(
  _VALUE.fields_by_name['blob_value'])
_VALUE.fields_by_name['blob_value'].containing_oneof = _VALUE.oneofs_by_name['value_type']
_ENTITY_PROPERTIESENTRY.fields_by_name['value'].message_type = _VALUE
_ENTITY_PROPERTIESENTRY.containing_type = _ENTITY
_ENTITY.fields_by_name['properties'].message_type = _ENTITY_PROPERTIESENTRY
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['Entity'] = _ENTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYVALUE,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.ArrayValue)
  ))
_sym_db.RegisterMessage(ArrayValue)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Value)
  ))
_sym_db.RegisterMessage(Value)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _ENTITY_PROPERTIESENTRY,
    __module__ = 'admobilize.common.entity_pb2'
    # @@protoc_insertion_point(class_scope:admobilize.common.Entity.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _ENTITY,
  __module__ = 'admobilize.common.entity_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Entity)
  ))
_sym_db.RegisterMessage(Entity)
_sym_db.RegisterMessage(Entity.PropertiesEntry)


DESCRIPTOR._options = None
_ENTITY_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/common/job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/common/job.proto',
  package='admobilize.common',
  syntax='proto3',
  serialized_options=_b('\n\025com.admobilize.commonB\010JobProtoP\001\242\002\003ACP\252\002 AdMobilize.common.WellKnownTypes'),
  serialized_pb=_b('\n\x1b\x61\x64mobilize/common/job.proto\x12\x11\x61\x64mobilize.common\x1a\x1fgoogle/protobuf/timestamp.proto\">\n\x08JobError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"\xa3\x01\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x13\n\x0bupdate_time\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12,\n\x06status\x18\x05 \x01(\x0e\x32\x1c.admobilize.common.JobStatus\x12*\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x1b.admobilize.common.JobError*3\n\tJobStatus\x12\x0b\n\x07RUNNING\x10\x00\x12\x0b\n\x07\x45RRORED\x10\x01\x12\x0c\n\x08\x46INISHED\x10\x02\x42L\n\x15\x63om.admobilize.commonB\x08JobProtoP\x01\xa2\x02\x03\x41\x43P\xaa\x02 AdMobilize.common.WellKnownTypesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_JOBSTATUS = _descriptor.EnumDescriptor(
  name='JobStatus',
  full_name='admobilize.common.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERRORED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=313,
  serialized_end=364,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATUS)

JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
RUNNING = 0
ERRORED = 1
FINISHED = 2



_JOBERROR = _descriptor.Descriptor(
  name='JobError',
  full_name='admobilize.common.JobError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='admobilize.common.JobError.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='admobilize.common.JobError.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='admobilize.common.JobError.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=145,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='admobilize.common.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.common.Job.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='admobilize.common.Job.create_time', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='admobilize.common.Job.update_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.common.Job.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='admobilize.common.Job.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='admobilize.common.Job.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=311,
)

_JOB.fields_by_name['status'].enum_type = _JOBSTATUS
_JOB.fields_by_name['error'].message_type = _JOBERROR
DESCRIPTOR.message_types_by_name['JobError'] = _JOBERROR
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.enum_types_by_name['JobStatus'] = _JOBSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobError = _reflection.GeneratedProtocolMessageType('JobError', (_message.Message,), dict(
  DESCRIPTOR = _JOBERROR,
  __module__ = 'admobilize.common.job_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.JobError)
  ))
_sym_db.RegisterMessage(JobError)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), dict(
  DESCRIPTOR = _JOB,
  __module__ = 'admobilize.common.job_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.common.Job)
  ))
_sym_db.RegisterMessage(Job)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from admobilize.proto.mlmodel.v1alpha1 import mlmodel_service_pb2 as admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class MLModelServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateModels = channel.unary_unary(
        '/admobilize.mlmodel.v1alpha1.MLModelService/CreateModels',
        request_serializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.CreateModelsRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetModels = channel.unary_unary(
        '/admobilize.mlmodel.v1alpha1.MLModelService/GetModels',
        request_serializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.GetModelsRequest.SerializeToString,
        response_deserializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.GetModelsResponse.FromString,
        )
    self.DeleteModels = channel.unary_unary(
        '/admobilize.mlmodel.v1alpha1.MLModelService/DeleteModels',
        request_serializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.DeleteModelsRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class MLModelServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateModels(self, request, context):
    """Create a set of Models in the API
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetModels(self, request, context):
    """Obtain a set of specific Models matching from the API
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteModels(self, request, context):
    """Delete a set of Models from the API
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MLModelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateModels': grpc.unary_unary_rpc_method_handler(
          servicer.CreateModels,
          request_deserializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.CreateModelsRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetModels': grpc.unary_unary_rpc_method_handler(
          servicer.GetModels,
          request_deserializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.GetModelsRequest.FromString,
          response_serializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.GetModelsResponse.SerializeToString,
      ),
      'DeleteModels': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteModels,
          request_deserializer=admobilize_dot_mlmodel_dot_v1alpha1_dot_mlmodel__service__pb2.DeleteModelsRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'admobilize.mlmodel.v1alpha1.MLModelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/devicemanagement/v1alpha1/resources.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from admobilize.proto.common import entity_pb2 as admobilize_dot_common_dot_entity__pb2
from admobilize.proto.billing.v1alpha1 import billing_pb2 as admobilize_dot_billing_dot_v1alpha1_dot_billing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/devicemanagement/v1alpha1/resources.proto',
  package='admobilize.devicemanagement.v1alpha1',
  syntax='proto3',
  serialized_options=_b('\n(com.admobilize.devicemanagement.v1alpha1B\013DeviceProtoP\001\242\002\005ADMDM\252\002$AdMobilize.DeviceManagement.V1Alpha1'),
  serialized_pb=_b('\n4admobilize/devicemanagement/v1alpha1/resources.proto\x12$admobilize.devicemanagement.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x61\x64mobilize/common/entity.proto\x1a)admobilize/billing/v1alpha1/billing.proto\"G\n\x03\x41\x63l\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1a\n\x12provisioning_token\x18\x03 \x01(\t\"_\n\tEntityAcl\x12\x12\n\nread_users\x18\x01 \x03(\t\x12\x13\n\x0bwrite_users\x18\x02 \x03(\t\x12\x13\n\x0bread_groups\x18\x03 \x03(\t\x12\x14\n\x0cwrite_groups\x18\x04 \x03(\t\"\xa1\x01\n\nProjectAcl\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12?\n\x06\x65ntity\x18\n \x01(\x0b\x32/.admobilize.devicemanagement.v1alpha1.EntityAcl\x12@\n\x07\x64\x65vices\x18\x14 \x01(\x0b\x32/.admobilize.devicemanagement.v1alpha1.EntityAcl\"\xbb\x02\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12=\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x30.admobilize.devicemanagement.v1alpha1.ProjectAcl\x12\x44\n\x0f\x62illing_account\x18\x04 \x01(\x0b\x32+.admobilize.billing.v1alpha1.BillingAccount\x12\x0f\n\x07\x64\x65vices\x18\x05 \x03(\t\x12I\n\x06labels\x18\x06 \x03(\x0b\x32\x39.admobilize.devicemanagement.v1alpha1.Project.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n\x0f\x41pplicationMeta\x12\x0f\n\x07version\x18\x01 \x01(\t\"\xc1\x01\n\x0b\x41pplication\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x03\x61\x63l\x18\x04 \x01(\x0b\x32).admobilize.devicemanagement.v1alpha1.Acl\x12)\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x19.admobilize.common.Entity\x12\x43\n\x04meta\x18\x06 \x01(\x0b\x32\x35.admobilize.devicemanagement.v1alpha1.ApplicationMeta\"1\n\x0c\x44\x65viceConfig\x12\x13\n\x0b\x61uto_update\x18\x01 \x01(\x08\x12\x0c\n\x04init\x18\x02 \x03(\t\"\xb2\x02\n\nDeviceMeta\x12/\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12L\n\x06labels\x18\x05 \x03(\x0b\x32<.admobilize.devicemanagement.v1alpha1.DeviceMeta.LabelsEntry\x12\x15\n\rmqtt_registry\x18\x06 \x01(\t\x12\x12\n\npublic_key\x18\x07 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x02\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32).admobilize.devicemanagement.v1alpha1.Acl\x12\x42\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x32.admobilize.devicemanagement.v1alpha1.DeviceConfig\x12>\n\x04meta\x18\x05 \x01(\x0b\x32\x30.admobilize.devicemanagement.v1alpha1.DeviceMeta\x12G\n\x0c\x61pplications\x18\x06 \x03(\x0b\x32\x31.admobilize.devicemanagement.v1alpha1.ApplicationBh\n(com.admobilize.devicemanagement.v1alpha1B\x0b\x44\x65viceProtoP\x01\xa2\x02\x05\x41\x44MDM\xaa\x02$AdMobilize.DeviceManagement.V1Alpha1b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,admobilize_dot_common_dot_entity__pb2.DESCRIPTOR,admobilize_dot_billing_dot_v1alpha1_dot_billing__pb2.DESCRIPTOR,])




_ACL = _descriptor.Descriptor(
  name='Acl',
  full_name='admobilize.devicemanagement.v1alpha1.Acl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='admobilize.devicemanagement.v1alpha1.Acl.owner_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='admobilize.devicemanagement.v1alpha1.Acl.project_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provisioning_token', full_name='admobilize.devicemanagement.v1alpha1.Acl.provisioning_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=273,
)


_ENTITYACL = _descriptor.Descriptor(
  name='EntityAcl',
  full_name='admobilize.devicemanagement.v1alpha1.EntityAcl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_users', full_name='admobilize.devicemanagement.v1alpha1.EntityAcl.read_users', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_users', full_name='admobilize.devicemanagement.v1alpha1.EntityAcl.write_users', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_groups', full_name='admobilize.devicemanagement.v1alpha1.EntityAcl.read_groups', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_groups', full_name='admobilize.devicemanagement.v1alpha1.EntityAcl.write_groups', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=370,
)


_PROJECTACL = _descriptor.Descriptor(
  name='ProjectAcl',
  full_name='admobilize.devicemanagement.v1alpha1.ProjectAcl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='admobilize.devicemanagement.v1alpha1.ProjectAcl.owner_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='admobilize.devicemanagement.v1alpha1.ProjectAcl.entity', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.ProjectAcl.devices', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=534,
)


_PROJECT_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='admobilize.devicemanagement.v1alpha1.Project.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='admobilize.devicemanagement.v1alpha1.Project.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='admobilize.devicemanagement.v1alpha1.Project.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=852,
)

_PROJECT = _descriptor.Descriptor(
  name='Project',
  full_name='admobilize.devicemanagement.v1alpha1.Project',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.Project.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='admobilize.devicemanagement.v1alpha1.Project.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl', full_name='admobilize.devicemanagement.v1alpha1.Project.acl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_account', full_name='admobilize.devicemanagement.v1alpha1.Project.billing_account', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.Project.devices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='admobilize.devicemanagement.v1alpha1.Project.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROJECT_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=852,
)


_APPLICATIONMETA = _descriptor.Descriptor(
  name='ApplicationMeta',
  full_name='admobilize.devicemanagement.v1alpha1.ApplicationMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='admobilize.devicemanagement.v1alpha1.ApplicationMeta.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=888,
)


_APPLICATION = _descriptor.Descriptor(
  name='Application',
  full_name='admobilize.devicemanagement.v1alpha1.Application',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.Application.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl', full_name='admobilize.devicemanagement.v1alpha1.Application.acl', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='admobilize.devicemanagement.v1alpha1.Application.config', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='admobilize.devicemanagement.v1alpha1.Application.meta', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=1084,
)


_DEVICECONFIG = _descriptor.Descriptor(
  name='DeviceConfig',
  full_name='admobilize.devicemanagement.v1alpha1.DeviceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_update', full_name='admobilize.devicemanagement.v1alpha1.DeviceConfig.auto_update', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='init', full_name='admobilize.devicemanagement.v1alpha1.DeviceConfig.init', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1135,
)


_DEVICEMETA_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=852,
)

_DEVICEMETA = _descriptor.Descriptor(
  name='DeviceMeta',
  full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_time', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.create_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.update_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mqtt_registry', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.mqtt_registry', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='admobilize.devicemanagement.v1alpha1.DeviceMeta.public_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEMETA_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1444,
)


_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='admobilize.devicemanagement.v1alpha1.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.Device.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='admobilize.devicemanagement.v1alpha1.Device.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl', full_name='admobilize.devicemanagement.v1alpha1.Device.acl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='admobilize.devicemanagement.v1alpha1.Device.config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='admobilize.devicemanagement.v1alpha1.Device.meta', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='applications', full_name='admobilize.devicemanagement.v1alpha1.Device.applications', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1742,
)

_PROJECTACL.fields_by_name['entity'].message_type = _ENTITYACL
_PROJECTACL.fields_by_name['devices'].message_type = _ENTITYACL
_PROJECT_LABELSENTRY.containing_type = _PROJECT
_PROJECT.fields_by_name['acl'].message_type = _PROJECTACL
_PROJECT.fields_by_name['billing_account'].message_type = admobilize_dot_billing_dot_v1alpha1_dot_billing__pb2._BILLINGACCOUNT
_PROJECT.fields_by_name['labels'].message_type = _PROJECT_LABELSENTRY
_APPLICATION.fields_by_name['acl'].message_type = _ACL
_APPLICATION.fields_by_name['config'].message_type = admobilize_dot_common_dot_entity__pb2._ENTITY
_APPLICATION.fields_by_name['meta'].message_type = _APPLICATIONMETA
_DEVICEMETA_LABELSENTRY.containing_type = _DEVICEMETA
_DEVICEMETA.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMETA.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DEVICEMETA.fields_by_name['labels'].message_type = _DEVICEMETA_LABELSENTRY
_DEVICE.fields_by_name['acl'].message_type = _ACL
_DEVICE.fields_by_name['config'].message_type = _DEVICECONFIG
_DEVICE.fields_by_name['meta'].message_type = _DEVICEMETA
_DEVICE.fields_by_name['applications'].message_type = _APPLICATION
DESCRIPTOR.message_types_by_name['Acl'] = _ACL
DESCRIPTOR.message_types_by_name['EntityAcl'] = _ENTITYACL
DESCRIPTOR.message_types_by_name['ProjectAcl'] = _PROJECTACL
DESCRIPTOR.message_types_by_name['Project'] = _PROJECT
DESCRIPTOR.message_types_by_name['ApplicationMeta'] = _APPLICATIONMETA
DESCRIPTOR.message_types_by_name['Application'] = _APPLICATION
DESCRIPTOR.message_types_by_name['DeviceConfig'] = _DEVICECONFIG
DESCRIPTOR.message_types_by_name['DeviceMeta'] = _DEVICEMETA
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Acl = _reflection.GeneratedProtocolMessageType('Acl', (_message.Message,), dict(
  DESCRIPTOR = _ACL,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.Acl)
  ))
_sym_db.RegisterMessage(Acl)

EntityAcl = _reflection.GeneratedProtocolMessageType('EntityAcl', (_message.Message,), dict(
  DESCRIPTOR = _ENTITYACL,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.EntityAcl)
  ))
_sym_db.RegisterMessage(EntityAcl)

ProjectAcl = _reflection.GeneratedProtocolMessageType('ProjectAcl', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTACL,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ProjectAcl)
  ))
_sym_db.RegisterMessage(ProjectAcl)

Project = _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PROJECT_LABELSENTRY,
    __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
    # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.Project.LabelsEntry)
    ))
  ,
  DESCRIPTOR = _PROJECT,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.Project)
  ))
_sym_db.RegisterMessage(Project)
_sym_db.RegisterMessage(Project.LabelsEntry)

ApplicationMeta = _reflection.GeneratedProtocolMessageType('ApplicationMeta', (_message.Message,), dict(
  DESCRIPTOR = _APPLICATIONMETA,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ApplicationMeta)
  ))
_sym_db.RegisterMessage(ApplicationMeta)

Application = _reflection.GeneratedProtocolMessageType('Application', (_message.Message,), dict(
  DESCRIPTOR = _APPLICATION,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.Application)
  ))
_sym_db.RegisterMessage(Application)

DeviceConfig = _reflection.GeneratedProtocolMessageType('DeviceConfig', (_message.Message,), dict(
  DESCRIPTOR = _DEVICECONFIG,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.DeviceConfig)
  ))
_sym_db.RegisterMessage(DeviceConfig)

DeviceMeta = _reflection.GeneratedProtocolMessageType('DeviceMeta', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _DEVICEMETA_LABELSENTRY,
    __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
    # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.DeviceMeta.LabelsEntry)
    ))
  ,
  DESCRIPTOR = _DEVICEMETA,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.DeviceMeta)
  ))
_sym_db.RegisterMessage(DeviceMeta)
_sym_db.RegisterMessage(DeviceMeta.LabelsEntry)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
  DESCRIPTOR = _DEVICE,
  __module__ = 'admobilize.devicemanagement.v1alpha1.resources_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.Device)
  ))
_sym_db.RegisterMessage(Device)


DESCRIPTOR._options = None
_PROJECT_LABELSENTRY._options = None
_DEVICEMETA_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/ayuda/v1alpha1/ayuda_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from admobilize.proto.common import job_pb2 as admobilize_dot_common_dot_job__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/ayuda/v1alpha1/ayuda_service.proto',
  package='admobilize.ayuda.v1alpha1',
  syntax='proto3',
  serialized_options=_b('\n\035com.admobilize.ayuda.v1alpha1B\021AyudaServiceProtoP\001\242\002\006ADMAYS\252\002\031AdMobilize.Ayuda.V1Alpha1'),
  serialized_pb=_b('\n-admobilize/ayuda/v1alpha1/ayuda_service.proto\x12\x19\x61\x64mobilize.ayuda.v1alpha1\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x61\x64mobilize/common/job.proto\"P\n\x0fSnapshotRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\"<\n\x18OptimizedSnapshotRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x10\n\x08snapshot\x18\x02 \x01(\t\"^\n\rReportRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x16\n\x0estart_datetime\x18\x02 \x01(\t\x12\x14\n\x0c\x65nd_datetime\x18\x03 \x01(\t\x12\x0f\n\x07\x64\x65vices\x18\x04 \x03(\t2\x85\x03\n\x0c\x41yudaService\x12p\n\x0e\x43reateSnapshot\x12*.admobilize.ayuda.v1alpha1.SnapshotRequest\x1a\x16.admobilize.common.Job\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/v1alpha/snapshots\x12\x82\x01\n\x17\x43reateOptimizedSnapshot\x12\x33.admobilize.ayuda.v1alpha1.OptimizedSnapshotRequest\x1a\x16.admobilize.common.Job\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/v1alpha/optimized\x12~\n\x0c\x43reateReport\x12(.admobilize.ayuda.v1alpha1.ReportRequest\x1a\x16.admobilize.common.Job\",\x82\xd3\xe4\x93\x02&\"$/v1alpha/{parent=projects/*}/reportsBY\n\x1d\x63om.admobilize.ayuda.v1alpha1B\x11\x41yudaServiceProtoP\x01\xa2\x02\x06\x41\x44MAYS\xaa\x02\x19\x41\x64Mobilize.Ayuda.V1Alpha1b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,admobilize_dot_common_dot_job__pb2.DESCRIPTOR,])




_SNAPSHOTREQUEST = _descriptor.Descriptor(
  name='SnapshotRequest',
  full_name='admobilize.ayuda.v1alpha1.SnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='admobilize.ayuda.v1alpha1.SnapshotRequest.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='admobilize.ayuda.v1alpha1.SnapshotRequest.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='admobilize.ayuda.v1alpha1.SnapshotRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='admobilize.ayuda.v1alpha1.SnapshotRequest.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=215,
)


_OPTIMIZEDSNAPSHOTREQUEST = _descriptor.Descriptor(
  name='OptimizedSnapshotRequest',
  full_name='admobilize.ayuda.v1alpha1.OptimizedSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='admobilize.ayuda.v1alpha1.OptimizedSnapshotRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='admobilize.ayuda.v1alpha1.OptimizedSnapshotRequest.snapshot', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=277,
)


_REPORTREQUEST = _descriptor.Descriptor(
  name='ReportRequest',
  full_name='admobilize.ayuda.v1alpha1.ReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='admobilize.ayuda.v1alpha1.ReportRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_datetime', full_name='admobilize.ayuda.v1alpha1.ReportRequest.start_datetime', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_datetime', full_name='admobilize.ayuda.v1alpha1.ReportRequest.end_datetime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.ayuda.v1alpha1.ReportRequest.devices', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=373,
)

DESCRIPTOR.message_types_by_name['SnapshotRequest'] = _SNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['OptimizedSnapshotRequest'] = _OPTIMIZEDSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['ReportRequest'] = _REPORTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SnapshotRequest = _reflection.GeneratedProtocolMessageType('SnapshotRequest', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTREQUEST,
  __module__ = 'admobilize.ayuda.v1alpha1.ayuda_service_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.ayuda.v1alpha1.SnapshotRequest)
  ))
_sym_db.RegisterMessage(SnapshotRequest)

OptimizedSnapshotRequest = _reflection.GeneratedProtocolMessageType('OptimizedSnapshotRequest', (_message.Message,), dict(
  DESCRIPTOR = _OPTIMIZEDSNAPSHOTREQUEST,
  __module__ = 'admobilize.ayuda.v1alpha1.ayuda_service_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.ayuda.v1alpha1.OptimizedSnapshotRequest)
  ))
_sym_db.RegisterMessage(OptimizedSnapshotRequest)

ReportRequest = _reflection.GeneratedProtocolMessageType('ReportRequest', (_message.Message,), dict(
  DESCRIPTOR = _REPORTREQUEST,
  __module__ = 'admobilize.ayuda.v1alpha1.ayuda_service_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.ayuda.v1alpha1.ReportRequest)
  ))
_sym_db.RegisterMessage(ReportRequest)


DESCRIPTOR._options = None

_AYUDASERVICE = _descriptor.ServiceDescriptor(
  name='AyudaService',
  full_name='admobilize.ayuda.v1alpha1.AyudaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=376,
  serialized_end=765,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSnapshot',
    full_name='admobilize.ayuda.v1alpha1.AyudaService.CreateSnapshot',
    index=0,
    containing_service=None,
    input_type=_SNAPSHOTREQUEST,
    output_type=admobilize_dot_common_dot_job__pb2._JOB,
    serialized_options=_b('\202\323\344\223\002\024\"\022/v1alpha/snapshots'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateOptimizedSnapshot',
    full_name='admobilize.ayuda.v1alpha1.AyudaService.CreateOptimizedSnapshot',
    index=1,
    containing_service=None,
    input_type=_OPTIMIZEDSNAPSHOTREQUEST,
    output_type=admobilize_dot_common_dot_job__pb2._JOB,
    serialized_options=_b('\202\323\344\223\002\024\"\022/v1alpha/optimized'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateReport',
    full_name='admobilize.ayuda.v1alpha1.AyudaService.CreateReport',
    index=2,
    containing_service=None,
    input_type=_REPORTREQUEST,
    output_type=admobilize_dot_common_dot_job__pb2._JOB,
    serialized_options=_b('\202\323\344\223\002&\"$/v1alpha/{parent=projects/*}/reports'),
  ),
])
_sym_db.RegisterServiceDescriptor(_AYUDASERVICE)

DESCRIPTOR.services_by_name['AyudaService'] = _AYUDASERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admobilize/devicemanagement/v1alpha1/device_manager.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from admobilize.proto.devicemanagement.v1alpha1 import resources_pb2 as admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admobilize/devicemanagement/v1alpha1/device_manager.proto',
  package='admobilize.devicemanagement.v1alpha1',
  syntax='proto3',
  serialized_options=_b('\n(com.admobilize.devicemanagement.v1alpha1B\022DeviceManagerProtoP\001\242\002\005ADMDM\252\002$AdMobilize.DeviceManagement.V1Alpha1'),
  serialized_pb=_b('\n9admobilize/devicemanagement/v1alpha1/device_manager.proto\x12$admobilize.devicemanagement.v1alpha1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x34\x61\x64mobilize/devicemanagement/v1alpha1/resources.proto\"N\n\x10GetDeviceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"{\n\x12ListDevicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tpage_size\x18\x64 \x01(\x05\x12\x12\n\npage_token\x18\x65 \x01(\t\"m\n\x13ListDevicesResponse\x12=\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x01\n\x13UpdateDeviceRequest\x12<\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"!\n\x13\x44\x65leteDeviceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"O\n\x11GetProjectRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"l\n\x13ListProjectsRequest\x12.\n\nfield_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tpage_size\x18\x64 \x01(\x05\x12\x12\n\npage_token\x18\x65 \x01(\t\"p\n\x14ListProjectsResponse\x12?\n\x08projects\x18\x01 \x03(\x0b\x32-.admobilize.devicemanagement.v1alpha1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x14UpdateProjectRequest\x12>\n\x07project\x18\x01 \x01(\x0b\x32-.admobilize.devicemanagement.v1alpha1.Project\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\"\n\x14\x44\x65leteProjectRequest\x12\n\n\x02id\x18\x01 \x01(\t\"Z\n\x19\x42\x61tchCreateDevicesRequest\x12=\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\"[\n\x1a\x42\x61tchCreateDevicesResponse\x12=\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\"X\n\x17ProvisionDevicesRequest\x12=\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\"Y\n\x18ProvisionDevicesResponse\x12=\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32,.admobilize.devicemanagement.v1alpha1.Device\")\n\x18VerifyDeviceTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t2\xe8\x08\n\rDeviceManager\x12\x88\x01\n\x0c\x43reateDevice\x12,.admobilize.devicemanagement.v1alpha1.Device\x1a,.admobilize.devicemanagement.v1alpha1.Device\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1alpha1/devices:\x01*\x12\x93\x01\n\tGetDevice\x12\x36.admobilize.devicemanagement.v1alpha1.GetDeviceRequest\x1a,.admobilize.devicemanagement.v1alpha1.Device\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1alpha1/{id=devices/*}\x12\x9d\x01\n\x0bListDevices\x12\x38.admobilize.devicemanagement.v1alpha1.ListDevicesRequest\x1a\x39.admobilize.devicemanagement.v1alpha1.ListDevicesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1alpha1/devices\x12\xa8\x01\n\x0cUpdateDevice\x12\x39.admobilize.devicemanagement.v1alpha1.UpdateDeviceRequest\x1a,.admobilize.devicemanagement.v1alpha1.Device\"/\x82\xd3\xe4\x93\x02)2\x1f/v1alpha1/{device.id=devices/*}:\x06\x64\x65vice\x12\x83\x01\n\x0c\x44\x65leteDevice\x12\x39.admobilize.devicemanagement.v1alpha1.DeleteDeviceRequest\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a*\x18/v1alpha1/{id=devices/*}\x12\xb9\x01\n\x10ProvisionDevices\x12=.admobilize.devicemanagement.v1alpha1.ProvisionDevicesRequest\x1a>.admobilize.devicemanagement.v1alpha1.ProvisionDevicesResponse\"&\x82\xd3\xe4\x93\x02 2\x1b/v1alpha1/devices/provision:\x01*\x12\xa8\x01\n\x11VerifyDeviceToken\x12>.admobilize.devicemanagement.v1alpha1.VerifyDeviceTokenRequest\x1a,.admobilize.devicemanagement.v1alpha1.Device\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1alpha1/devicetokens/verifyBo\n(com.admobilize.devicemanagement.v1alpha1B\x12\x44\x65viceManagerProtoP\x01\xa2\x02\x05\x41\x44MDM\xaa\x02$AdMobilize.DeviceManagement.V1Alpha1b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2.DESCRIPTOR,])




_GETDEVICEREQUEST = _descriptor.Descriptor(
  name='GetDeviceRequest',
  full_name='admobilize.devicemanagement.v1alpha1.GetDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.GetDeviceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask', full_name='admobilize.devicemanagement.v1alpha1.GetDeviceRequest.field_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=324,
)


_LISTDEVICESREQUEST = _descriptor.Descriptor(
  name='ListDevicesRequest',
  full_name='admobilize.devicemanagement.v1alpha1.ListDevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesRequest.field_mask', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesRequest.page_size', index=2,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesRequest.page_token', index=3,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=449,
)


_LISTDEVICESRESPONSE = _descriptor.Descriptor(
  name='ListDevicesResponse',
  full_name='admobilize.devicemanagement.v1alpha1.ListDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesResponse.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='admobilize.devicemanagement.v1alpha1.ListDevicesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=560,
)


_UPDATEDEVICEREQUEST = _descriptor.Descriptor(
  name='UpdateDeviceRequest',
  full_name='admobilize.devicemanagement.v1alpha1.UpdateDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='admobilize.devicemanagement.v1alpha1.UpdateDeviceRequest.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='admobilize.devicemanagement.v1alpha1.UpdateDeviceRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=695,
)


_DELETEDEVICEREQUEST = _descriptor.Descriptor(
  name='DeleteDeviceRequest',
  full_name='admobilize.devicemanagement.v1alpha1.DeleteDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.DeleteDeviceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=730,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='admobilize.devicemanagement.v1alpha1.GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.GetProjectRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask', full_name='admobilize.devicemanagement.v1alpha1.GetProjectRequest.field_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=811,
)


_LISTPROJECTSREQUEST = _descriptor.Descriptor(
  name='ListProjectsRequest',
  full_name='admobilize.devicemanagement.v1alpha1.ListProjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_mask', full_name='admobilize.devicemanagement.v1alpha1.ListProjectsRequest.field_mask', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='admobilize.devicemanagement.v1alpha1.ListProjectsRequest.page_size', index=1,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='admobilize.devicemanagement.v1alpha1.ListProjectsRequest.page_token', index=2,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=921,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='admobilize.devicemanagement.v1alpha1.ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='admobilize.devicemanagement.v1alpha1.ListProjectsResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='admobilize.devicemanagement.v1alpha1.ListProjectsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1035,
)


_UPDATEPROJECTREQUEST = _descriptor.Descriptor(
  name='UpdateProjectRequest',
  full_name='admobilize.devicemanagement.v1alpha1.UpdateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='admobilize.devicemanagement.v1alpha1.UpdateProjectRequest.project', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='admobilize.devicemanagement.v1alpha1.UpdateProjectRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1173,
)


_DELETEPROJECTREQUEST = _descriptor.Descriptor(
  name='DeleteProjectRequest',
  full_name='admobilize.devicemanagement.v1alpha1.DeleteProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='admobilize.devicemanagement.v1alpha1.DeleteProjectRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1209,
)


_BATCHCREATEDEVICESREQUEST = _descriptor.Descriptor(
  name='BatchCreateDevicesRequest',
  full_name='admobilize.devicemanagement.v1alpha1.BatchCreateDevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.BatchCreateDevicesRequest.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1301,
)


_BATCHCREATEDEVICESRESPONSE = _descriptor.Descriptor(
  name='BatchCreateDevicesResponse',
  full_name='admobilize.devicemanagement.v1alpha1.BatchCreateDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.BatchCreateDevicesResponse.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1394,
)


_PROVISIONDEVICESREQUEST = _descriptor.Descriptor(
  name='ProvisionDevicesRequest',
  full_name='admobilize.devicemanagement.v1alpha1.ProvisionDevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.ProvisionDevicesRequest.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1396,
  serialized_end=1484,
)


_PROVISIONDEVICESRESPONSE = _descriptor.Descriptor(
  name='ProvisionDevicesResponse',
  full_name='admobilize.devicemanagement.v1alpha1.ProvisionDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='admobilize.devicemanagement.v1alpha1.ProvisionDevicesResponse.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1486,
  serialized_end=1575,
)


_VERIFYDEVICETOKENREQUEST = _descriptor.Descriptor(
  name='VerifyDeviceTokenRequest',
  full_name='admobilize.devicemanagement.v1alpha1.VerifyDeviceTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='admobilize.devicemanagement.v1alpha1.VerifyDeviceTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1577,
  serialized_end=1618,
)

_GETDEVICEREQUEST.fields_by_name['field_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTDEVICESREQUEST.fields_by_name['field_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTDEVICESRESPONSE.fields_by_name['devices'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
_UPDATEDEVICEREQUEST.fields_by_name['device'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
_UPDATEDEVICEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_GETPROJECTREQUEST.fields_by_name['field_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTPROJECTSREQUEST.fields_by_name['field_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTPROJECTSRESPONSE.fields_by_name['projects'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._PROJECT
_UPDATEPROJECTREQUEST.fields_by_name['project'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._PROJECT
_UPDATEPROJECTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_BATCHCREATEDEVICESREQUEST.fields_by_name['devices'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
_BATCHCREATEDEVICESRESPONSE.fields_by_name['devices'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
_PROVISIONDEVICESREQUEST.fields_by_name['devices'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
_PROVISIONDEVICESRESPONSE.fields_by_name['devices'].message_type = admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE
DESCRIPTOR.message_types_by_name['GetDeviceRequest'] = _GETDEVICEREQUEST
DESCRIPTOR.message_types_by_name['ListDevicesRequest'] = _LISTDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ListDevicesResponse'] = _LISTDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDeviceRequest'] = _UPDATEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDeviceRequest'] = _DELETEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsRequest'] = _LISTPROJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateProjectRequest'] = _UPDATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteProjectRequest'] = _DELETEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['BatchCreateDevicesRequest'] = _BATCHCREATEDEVICESREQUEST
DESCRIPTOR.message_types_by_name['BatchCreateDevicesResponse'] = _BATCHCREATEDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['ProvisionDevicesRequest'] = _PROVISIONDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ProvisionDevicesResponse'] = _PROVISIONDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['VerifyDeviceTokenRequest'] = _VERIFYDEVICETOKENREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDeviceRequest = _reflection.GeneratedProtocolMessageType('GetDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDEVICEREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.GetDeviceRequest)
  ))
_sym_db.RegisterMessage(GetDeviceRequest)

ListDevicesRequest = _reflection.GeneratedProtocolMessageType('ListDevicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTDEVICESREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ListDevicesRequest)
  ))
_sym_db.RegisterMessage(ListDevicesRequest)

ListDevicesResponse = _reflection.GeneratedProtocolMessageType('ListDevicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTDEVICESRESPONSE,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ListDevicesResponse)
  ))
_sym_db.RegisterMessage(ListDevicesResponse)

UpdateDeviceRequest = _reflection.GeneratedProtocolMessageType('UpdateDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEDEVICEREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.UpdateDeviceRequest)
  ))
_sym_db.RegisterMessage(UpdateDeviceRequest)

DeleteDeviceRequest = _reflection.GeneratedProtocolMessageType('DeleteDeviceRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEDEVICEREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.DeleteDeviceRequest)
  ))
_sym_db.RegisterMessage(DeleteDeviceRequest)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPROJECTREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.GetProjectRequest)
  ))
_sym_db.RegisterMessage(GetProjectRequest)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPROJECTSREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ListProjectsRequest)
  ))
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPROJECTSRESPONSE,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ListProjectsResponse)
  ))
_sym_db.RegisterMessage(ListProjectsResponse)

UpdateProjectRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPROJECTREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.UpdateProjectRequest)
  ))
_sym_db.RegisterMessage(UpdateProjectRequest)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEPROJECTREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.DeleteProjectRequest)
  ))
_sym_db.RegisterMessage(DeleteProjectRequest)

BatchCreateDevicesRequest = _reflection.GeneratedProtocolMessageType('BatchCreateDevicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHCREATEDEVICESREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.BatchCreateDevicesRequest)
  ))
_sym_db.RegisterMessage(BatchCreateDevicesRequest)

BatchCreateDevicesResponse = _reflection.GeneratedProtocolMessageType('BatchCreateDevicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHCREATEDEVICESRESPONSE,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.BatchCreateDevicesResponse)
  ))
_sym_db.RegisterMessage(BatchCreateDevicesResponse)

ProvisionDevicesRequest = _reflection.GeneratedProtocolMessageType('ProvisionDevicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROVISIONDEVICESREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ProvisionDevicesRequest)
  ))
_sym_db.RegisterMessage(ProvisionDevicesRequest)

ProvisionDevicesResponse = _reflection.GeneratedProtocolMessageType('ProvisionDevicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROVISIONDEVICESRESPONSE,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.ProvisionDevicesResponse)
  ))
_sym_db.RegisterMessage(ProvisionDevicesResponse)

VerifyDeviceTokenRequest = _reflection.GeneratedProtocolMessageType('VerifyDeviceTokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYDEVICETOKENREQUEST,
  __module__ = 'admobilize.devicemanagement.v1alpha1.device_manager_pb2'
  # @@protoc_insertion_point(class_scope:admobilize.devicemanagement.v1alpha1.VerifyDeviceTokenRequest)
  ))
_sym_db.RegisterMessage(VerifyDeviceTokenRequest)


DESCRIPTOR._options = None

_DEVICEMANAGER = _descriptor.ServiceDescriptor(
  name='DeviceManager',
  full_name='admobilize.devicemanagement.v1alpha1.DeviceManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1621,
  serialized_end=2749,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDevice',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.CreateDevice',
    index=0,
    containing_service=None,
    input_type=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE,
    output_type=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE,
    serialized_options=_b('\202\323\344\223\002\026\"\021/v1alpha1/devices:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.GetDevice',
    index=1,
    containing_service=None,
    input_type=_GETDEVICEREQUEST,
    output_type=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE,
    serialized_options=_b('\202\323\344\223\002\032\022\030/v1alpha1/{id=devices/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListDevices',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.ListDevices',
    index=2,
    containing_service=None,
    input_type=_LISTDEVICESREQUEST,
    output_type=_LISTDEVICESRESPONSE,
    serialized_options=_b('\202\323\344\223\002\023\022\021/v1alpha1/devices'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDevice',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.UpdateDevice',
    index=3,
    containing_service=None,
    input_type=_UPDATEDEVICEREQUEST,
    output_type=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE,
    serialized_options=_b('\202\323\344\223\002)2\037/v1alpha1/{device.id=devices/*}:\006device'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDevice',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.DeleteDevice',
    index=4,
    containing_service=None,
    input_type=_DELETEDEVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\202\323\344\223\002\032*\030/v1alpha1/{id=devices/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='ProvisionDevices',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.ProvisionDevices',
    index=5,
    containing_service=None,
    input_type=_PROVISIONDEVICESREQUEST,
    output_type=_PROVISIONDEVICESRESPONSE,
    serialized_options=_b('\202\323\344\223\002 2\033/v1alpha1/devices/provision:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='VerifyDeviceToken',
    full_name='admobilize.devicemanagement.v1alpha1.DeviceManager.VerifyDeviceToken',
    index=6,
    containing_service=None,
    input_type=_VERIFYDEVICETOKENREQUEST,
    output_type=admobilize_dot_devicemanagement_dot_v1alpha1_dot_resources__pb2._DEVICE,
    serialized_options=_b('\202\323\344\223\002\037\022\035/v1alpha1/devicetokens/verify'),
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVICEMANAGER)

DESCRIPTOR.services_by_name['DeviceManager'] = _DEVICEMANAGER

# @@protoc_insertion_point(module_scope)



""" Setup module for AdMobilizeAPIs

See:
https://www.bitbucket.org/admobilize/admobilizeapis
"""

import setuptools

from setuptools import setup, find_packages

install_requires = [
  'google-api-core >= 0.1.2, < 0.2.0dev',
  'protobuf==3.6.0'
]

extras_require = {
  'grpc': ['grpcio>=1.2.0']
}

setuptools.setup(
  name='admobilizeapis',
  version='0.0.5',
  author='AdMobilize Team',
  author_email='devel@admobilize.com',
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
  description='Protobufs used in AdMobilize Ecosystem',
  long_description='Protobuf message definition for AdMobilize services',
  install_requires=install_requires,
  extras_require=extras_require,
  license='GPLv3',
  namespace_packages=[
    'admobilize',
  ],
  packages=find_packages(),
  url='https://www.bitbucket.org/admobilize/admobilizeapis'
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from admobilize.proto.ayuda.v1alpha1 import ayuda_service_pb2 as admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2
from admobilize.proto.common import job_pb2 as admobilize_dot_common_dot_job__pb2


class AyudaServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateSnapshot = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateSnapshot',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.SnapshotRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )
    self.CreateOptimizedSnapshot = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateOptimizedSnapshot',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.OptimizedSnapshotRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )
    self.CreateReport = channel.unary_unary(
        '/admobilize.ayuda.v1alpha1.AyudaService/CreateReport',
        request_serializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.ReportRequest.SerializeToString,
        response_deserializer=admobilize_dot_common_dot_job__pb2.Job.FromString,
        )


class AyudaServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateSnapshot(self, request, context):
    """Run the Ayuda snapshotting pipeline
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateOptimizedSnapshot(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateReport(self, request, context):
    """Run the Ayuda reporting pipeline
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AyudaServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.CreateSnapshot,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.SnapshotRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
      'CreateOptimizedSnapshot': grpc.unary_unary_rpc_method_handler(
          servicer.CreateOptimizedSnapshot,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.OptimizedSnapshotRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
      'CreateReport': grpc.unary_unary_rpc_method_handler(
          servicer.CreateReport,
          request_deserializer=admobilize_dot_ayuda_dot_v1alpha1_dot_ayuda__service__pb2.ReportRequest.FromString,
          response_serializer=admobilize_dot_common_dot_job__pb2.Job.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'admobilize.ayuda.v1alpha1.AyudaService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
